@@ -13,4 +13,9 @@ sub is_implemented(&) {
 
 sub zero_but_true($) { return ($_[0] and $_[0] == 0); }
 
+sub make_semname {
+	my $name = "unlikely_to_exist.$$";
+	return ($^O eq 'dec_osf') ? "/tmp/$name" : $name;
+}
+
 1;
